@@ -1,9 +1,8 @@
 """
 DeepSearch Toolkit
 """
-
 from .core import DeepSearchBearerTokenAuth, DeepSearchConfig, DeepSearchKeyAuth
 from .core.util._version import version
 from .cps import CpsApi, CpsApiClient
 from .cps.data_indices import utils
-from .documents import convert_document
+from .documents import convert_documents
