@@ -1,13 +1,14 @@
 import os
 import tempfile
 from pathlib import Path
-from typing import List
+from typing import List, Optional
 
 import urllib3
 
 from deepsearch.cps.client.api import CpsApi
 from deepsearch.cps.client.components.documents import DocumentConversionResult
 
+from .models import ExportTarget
 from .utils import batch_single_files
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
@@ -20,7 +21,11 @@ from .convert import (
 
 
 def process_local_input(
-    api: CpsApi, cps_proj_key: str, source_path: Path, progress_bar=False
+    api: CpsApi,
+    cps_proj_key: str,
+    source_path: Path,
+    target: Optional[ExportTarget],
+    progress_bar=False,
 ) -> DocumentConversionResult:
     """
     Classify the user provided local input and take appropriate action.
@@ -38,6 +43,7 @@ def process_local_input(
                 api=api,
                 cps_proj_key=cps_proj_key,
                 source_path=source_path,
+                target=target,
                 root_dir=Path(tmpdir),
                 progress_bar=progress_bar,
             )
@@ -53,17 +59,26 @@ def process_local_input(
             statuses=statuses,
             source_path=source_path,
             api=api,
+            batched_files=batched_files,
         )
 
 
 def process_urls_input(
-    api: CpsApi, cps_proj_key: str, urls: List[str], progress_bar=False
+    api: CpsApi,
+    cps_proj_key: str,
+    urls: List[str],
+    target: Optional[ExportTarget],
+    progress_bar=False,
 ):
     """
     Classify user provided url(s) and take appropriate action.
     """
     task_ids = send_urls_for_conversion(
-        api=api, cps_proj_key=cps_proj_key, urls=urls, progress_bar=progress_bar
+        api=api,
+        cps_proj_key=cps_proj_key,
+        urls=urls,
+        target=target,
+        progress_bar=progress_bar,
     )
     statuses = check_status_running_tasks(
         api=api, cps_proj_key=cps_proj_key, task_ids=task_ids, progress_bar=progress_bar
